@@ -26,47 +26,49 @@ def check_no_collection(func):
     def _wrapper(self, value):
         if isinstance(value, (list, dict, set)):
             raise ValueError(
-                "The %s type doesn't accept collections as value" % (
-                    self.__class__.__name__))
+                "The %s type doesn't accept collections as value"
+                % (self.__class__.__name__)
+            )
 
         return func(self, value)
+
     return _wrapper
 
 
 ##
 # Primitive types
 class String(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('string')
+    _default_qname = xsd_ns("string")
     accepted_types = six.string_types
 
     @check_no_collection
     def xmlvalue(self, value):
         if isinstance(value, bytes):
-            return value.decode('utf-8')
-        return six.text_type(value if value is not None else '')
+            return value.decode("utf-8")
+        return six.text_type(value if value is not None else "")
 
     def pythonvalue(self, value):
         return value
 
 
 class Boolean(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('boolean')
+    _default_qname = xsd_ns("boolean")
     accepted_types = (bool,)
 
     @check_no_collection
     def xmlvalue(self, value):
-        return 'true' if value and value not in ('false', '0') else 'false'
+        return "true" if value and value not in ("false", "0") else "false"
 
     def pythonvalue(self, value):
         """Return True if the 'true' or '1'. 'false' and '0' are legal false
         values, but we consider everything not true as false.
 
         """
-        return value in ('true', '1')
+        return value in ("true", "1")
 
 
 class Decimal(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('decimal')
+    _default_qname = xsd_ns("decimal")
     accepted_types = (_Decimal, float) + six.string_types
 
     @check_no_collection
@@ -78,7 +80,7 @@ class Decimal(BuiltinType, AnySimpleType):
 
 
 class Float(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('float')
+    _default_qname = xsd_ns("float")
     accepted_types = (float, _Decimal) + six.string_types
 
     def xmlvalue(self, value):
@@ -89,7 +91,7 @@ class Float(BuiltinType, AnySimpleType):
 
 
 class Double(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('double')
+    _default_qname = xsd_ns("double")
     accepted_types = (_Decimal, float) + six.string_types
 
     @check_no_collection
@@ -101,7 +103,7 @@ class Double(BuiltinType, AnySimpleType):
 
 
 class Duration(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('duration')
+    _default_qname = xsd_ns("duration")
     accepted_types = (isodate.duration.Duration,) + six.string_types
 
     @check_no_collection
@@ -109,8 +111,8 @@ class Duration(BuiltinType, AnySimpleType):
         return isodate.duration_isoformat(value)
 
     def pythonvalue(self, value):
-        if value.startswith('PT-'):
-            value = value.replace('PT-', 'PT')
+        if value.startswith("PT-"):
+            value = value.replace("PT-", "PT")
             result = isodate.parse_duration(value)
             return datetime.timedelta(0 - result.total_seconds())
         else:
@@ -118,7 +120,7 @@ class Duration(BuiltinType, AnySimpleType):
 
 
 class DateTime(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('dateTime')
+    _default_qname = xsd_ns("dateTime")
     accepted_types = (datetime.datetime,) + six.string_types
 
     @check_no_collection
@@ -129,27 +131,31 @@ class DateTime(BuiltinType, AnySimpleType):
         # Bit of a hack, since datetime is a subclass of date we can't just
         # test it with an isinstance(). And actually, we should not really
         # care about the type, as long as it has the required attributes
-        if not all(hasattr(value, attr) for attr in ('hour', 'minute', 'second')):
-            value = datetime.datetime.combine(value, datetime.time(
-                getattr(value, 'hour', 0),
-                getattr(value, 'minute', 0),
-                getattr(value, 'second', 0)))
+        if not all(hasattr(value, attr) for attr in ("hour", "minute", "second")):
+            value = datetime.datetime.combine(
+                value,
+                datetime.time(
+                    getattr(value, "hour", 0),
+                    getattr(value, "minute", 0),
+                    getattr(value, "second", 0),
+                ),
+            )
 
-        if getattr(value, 'microsecond', 0):
-            return isodate.isostrf.strftime(value, '%Y-%m-%dT%H:%M:%S.%f%Z')
-        return isodate.isostrf.strftime(value, '%Y-%m-%dT%H:%M:%S%Z')
+        if getattr(value, "microsecond", 0):
+            return isodate.isostrf.strftime(value, "%Y-%m-%dT%H:%M:%S.%f%Z")
+        return isodate.isostrf.strftime(value, "%Y-%m-%dT%H:%M:%S%Z")
 
     def pythonvalue(self, value):
 
         # Determine based on the length of the value if it only contains a date
         # lazy hack ;-)
         if len(value) == 10:
-            value += 'T00:00:00'
+            value += "T00:00:00"
         return isodate.parse_datetime(value)
 
 
 class Time(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('time')
+    _default_qname = xsd_ns("time")
     accepted_types = (datetime.time,) + six.string_types
 
     @check_no_collection
@@ -158,22 +164,22 @@ class Time(BuiltinType, AnySimpleType):
             return value
 
         if value.microsecond:
-            return isodate.isostrf.strftime(value, '%H:%M:%S.%f%Z')
-        return isodate.isostrf.strftime(value, '%H:%M:%S%Z')
+            return isodate.isostrf.strftime(value, "%H:%M:%S.%f%Z")
+        return isodate.isostrf.strftime(value, "%H:%M:%S%Z")
 
     def pythonvalue(self, value):
         return isodate.parse_time(value)
 
 
 class Date(BuiltinType, AnySimpleType):
-    _default_qname = xsd_ns('date')
+    _default_qname = xsd_ns("date")
     accepted_types = (datetime.date,) + six.string_types
 
     @check_no_collection
     def xmlvalue(self, value):
         if isinstance(value, six.string_types):
             return value
-        return isodate.isostrf.strftime(value, '%Y-%m-%d')
+        return isodate.isostrf.strftime(value, "%Y-%m-%d")
 
     def pythonvalue(self, value):
         return isodate.parse_date(value)
@@ -186,15 +192,17 @@ class gYearMonth(BuiltinType, AnySimpleType):
     Lexical representation: CCYY-MM
 
     """
+
     accepted_types = (datetime.date,) + six.string_types
-    _default_qname = xsd_ns('gYearMonth')
+    _default_qname = xsd_ns("gYearMonth")
     _pattern = re.compile(
-        r'^(?P<year>-?\d{4,})-(?P<month>\d\d)(?P<timezone>Z|[-+]\d\d:?\d\d)?$')
+        r"^(?P<year>-?\d{4,})-(?P<month>\d\d)(?P<timezone>Z|[-+]\d\d:?\d\d)?$"
+    )
 
     @check_no_collection
     def xmlvalue(self, value):
         year, month, tzinfo = value
-        return '%04d-%02d%s' % (year, month, _unparse_timezone(tzinfo))
+        return "%04d-%02d%s" % (year, month, _unparse_timezone(tzinfo))
 
     def pythonvalue(self, value):
         match = self._pattern.match(value)
@@ -202,8 +210,10 @@ class gYearMonth(BuiltinType, AnySimpleType):
             raise ParseError()
         group = match.groupdict()
         return (
-            int(group['year']), int(group['month']),
-            _parse_timezone(group['timezone']))
+            int(group["year"]),
+            int(group["month"]),
+            _parse_timezone(group["timezone"]),
+        )
 
 
 class gYear(BuiltinType, AnySimpleType):
@@ -212,21 +222,22 @@ class gYear(BuiltinType, AnySimpleType):
     Lexical representation: CCYY
 
     """
+
     accepted_types = (datetime.date,) + six.string_types
-    _default_qname = xsd_ns('gYear')
-    _pattern = re.compile(r'^(?P<year>-?\d{4,})(?P<timezone>Z|[-+]\d\d:?\d\d)?$')
+    _default_qname = xsd_ns("gYear")
+    _pattern = re.compile(r"^(?P<year>-?\d{4,})(?P<timezone>Z|[-+]\d\d:?\d\d)?$")
 
     @check_no_collection
     def xmlvalue(self, value):
         year, tzinfo = value
-        return '%04d%s' % (year, _unparse_timezone(tzinfo))
+        return "%04d%s" % (year, _unparse_timezone(tzinfo))
 
     def pythonvalue(self, value):
         match = self._pattern.match(value)
         if not match:
             raise ParseError()
         group = match.groupdict()
-        return (int(group['year']), _parse_timezone(group['timezone']))
+        return (int(group["year"]), _parse_timezone(group["timezone"]))
 
 
 class gMonthDay(BuiltinType, AnySimpleType):
@@ -236,15 +247,17 @@ class gMonthDay(BuiltinType, AnySimpleType):
     Lexical representation: --MM-DD
 
     """
-    accepted_types = (datetime.date, ) + six.string_types
-    _default_qname = xsd_ns('gMonthDay')
+
+    accepted_types = (datetime.date,) + six.string_types
+    _default_qname = xsd_ns("gMonthDay")
     _pattern = re.compile(
-        r'^--(?P<month>\d\d)-(?P<day>\d\d)(?P<timezone>Z|[-+]\d\d:?\d\d)?$')
+        r"^--(?P<month>\d\d)-(?P<day>\d\d)(?P<timezone>Z|[-+]\d\d:?\d\d)?$"
+    )
 
     @check_no_collection
     def xmlvalue(self, value):
         month, day, tzinfo = value
-        return '--%02d-%02d%s' % (month, day, _unparse_timezone(tzinfo))
+        return "--%02d-%02d%s" % (month, day, _unparse_timezone(tzinfo))
 
     def pythonvalue(self, value):
         match = self._pattern.match(value)
@@ -253,8 +266,10 @@ class gMonthDay(BuiltinType, AnySimpleType):
 
         group = match.groupdict()
         return (
-            int(group['month']), int(group['day']),
-            _parse_timezone(group['timezone']))
+            int(group["month"]),
+            int(group["day"]),
+            _parse_timezone(group["timezone"]),
+        )
 
 
 class gDay(BuiltinType, AnySimpleType):
@@ -264,21 +279,22 @@ class gDay(BuiltinType, AnySimpleType):
     Lexical representation: ---DD
 
     """
+
     accepted_types = (datetime.date,) + six.string_types
-    _default_qname = xsd_ns('gDay')
-    _pattern = re.compile(r'^---(?P<day>\d\d)(?P<timezone>Z|[-+]\d\d:?\d\d)?$')
+    _default_qname = xsd_ns("gDay")
+    _pattern = re.compile(r"^---(?P<day>\d\d)(?P<timezone>Z|[-+]\d\d:?\d\d)?$")
 
     @check_no_collection
     def xmlvalue(self, value):
         day, tzinfo = value
-        return '---%02d%s' % (day, _unparse_timezone(tzinfo))
+        return "---%02d%s" % (day, _unparse_timezone(tzinfo))
 
     def pythonvalue(self, value):
         match = self._pattern.match(value)
         if not match:
             raise ParseError()
         group = match.groupdict()
-        return (int(group['day']), _parse_timezone(group['timezone']))
+        return (int(group["day"]), _parse_timezone(group["timezone"]))
 
 
 class gMonth(BuiltinType, AnySimpleType):
@@ -287,26 +303,27 @@ class gMonth(BuiltinType, AnySimpleType):
     Lexical representation: --MM
 
     """
+
     accepted_types = (datetime.date,) + six.string_types
-    _default_qname = xsd_ns('gMonth')
-    _pattern = re.compile(r'^--(?P<month>\d\d)(?P<timezone>Z|[-+]\d\d:?\d\d)?$')
+    _default_qname = xsd_ns("gMonth")
+    _pattern = re.compile(r"^--(?P<month>\d\d)(?P<timezone>Z|[-+]\d\d:?\d\d)?$")
 
     @check_no_collection
     def xmlvalue(self, value):
         month, tzinfo = value
-        return '--%d%s' % (month, _unparse_timezone(tzinfo))
+        return "--%d%s" % (month, _unparse_timezone(tzinfo))
 
     def pythonvalue(self, value):
         match = self._pattern.match(value)
         if not match:
             raise ParseError()
         group = match.groupdict()
-        return (int(group['month']), _parse_timezone(group['timezone']))
+        return (int(group["month"]), _parse_timezone(group["timezone"]))
 
 
 class HexBinary(BuiltinType, AnySimpleType):
     accepted_types = six.string_types
-    _default_qname = xsd_ns('hexBinary')
+    _default_qname = xsd_ns("hexBinary")
 
     @check_no_collection
     def xmlvalue(self, value):
@@ -318,7 +335,7 @@ class HexBinary(BuiltinType, AnySimpleType):
 
 class Base64Binary(BuiltinType, AnySimpleType):
     accepted_types = six.string_types
-    _default_qname = xsd_ns('base64Binary')
+    _default_qname = xsd_ns("base64Binary")
 
     @check_no_collection
     def xmlvalue(self, value):
@@ -330,7 +347,7 @@ class Base64Binary(BuiltinType, AnySimpleType):
 
 class AnyURI(BuiltinType, AnySimpleType):
     accepted_types = six.string_types
-    _default_qname = xsd_ns('anyURI')
+    _default_qname = xsd_ns("anyURI")
 
     @check_no_collection
     def xmlvalue(self, value):
@@ -342,7 +359,7 @@ class AnyURI(BuiltinType, AnySimpleType):
 
 class QName(BuiltinType, AnySimpleType):
     accepted_types = six.string_types
-    _default_qname = xsd_ns('QName')
+    _default_qname = xsd_ns("QName")
 
     @check_no_collection
     def xmlvalue(self, value):
@@ -354,62 +371,63 @@ class QName(BuiltinType, AnySimpleType):
 
 class Notation(BuiltinType, AnySimpleType):
     accepted_types = six.string_types
-    _default_qname = xsd_ns('NOTATION')
+    _default_qname = xsd_ns("NOTATION")
 
 
 ##
 # Derived datatypes
 
+
 class NormalizedString(String):
-    _default_qname = xsd_ns('normalizedString')
+    _default_qname = xsd_ns("normalizedString")
 
 
 class Token(NormalizedString):
-    _default_qname = xsd_ns('token')
+    _default_qname = xsd_ns("token")
 
 
 class Language(Token):
-    _default_qname = xsd_ns('language')
+    _default_qname = xsd_ns("language")
 
 
 class NmToken(Token):
-    _default_qname = xsd_ns('NMTOKEN')
+    _default_qname = xsd_ns("NMTOKEN")
 
 
 class NmTokens(NmToken):
-    _default_qname = xsd_ns('NMTOKENS')
+    _default_qname = xsd_ns("NMTOKENS")
 
 
 class Name(Token):
-    _default_qname = xsd_ns('Name')
+    _default_qname = xsd_ns("Name")
 
 
 class NCName(Name):
-    _default_qname = xsd_ns('NCName')
+    _default_qname = xsd_ns("NCName")
 
 
 class ID(NCName):
-    _default_qname = xsd_ns('ID')
+    _default_qname = xsd_ns("ID")
 
 
 class IDREF(NCName):
-    _default_qname = xsd_ns('IDREF')
+    _default_qname = xsd_ns("IDREF")
 
 
 class IDREFS(IDREF):
-    _default_qname = xsd_ns('IDREFS')
+    _default_qname = xsd_ns("IDREFS")
 
 
 class Entity(NCName):
-    _default_qname = xsd_ns('ENTITY')
+    _default_qname = xsd_ns("ENTITY")
 
 
 class Entities(Entity):
-    _default_qname = xsd_ns('ENTITIES')
+    _default_qname = xsd_ns("ENTITIES")
 
 
 class Integer(Decimal):
-    _default_qname = xsd_ns('integer')
+    _default_qname = xsd_ns("integer")
     accepted_types = (int, float) + six.string_types
 
     def xmlvalue(self, value):
@@ -420,55 +438,56 @@ class Integer(Decimal):
 
 
 class NonPositiveInteger(Integer):
-    _default_qname = xsd_ns('nonPositiveInteger')
+    _default_qname = xsd_ns("nonPositiveInteger")
 
 
 class NegativeInteger(Integer):
-    _default_qname = xsd_ns('negativeInteger')
+    _default_qname = xsd_ns("negativeInteger")
 
 
 class Long(Integer):
-    _default_qname = xsd_ns('long')
+    _default_qname = xsd_ns("long")
 
     def pythonvalue(self, value):
         return long(value) if six.PY2 else int(value)  # noqa
 
 
 class Int(Long):
-    _default_qname = xsd_ns('int')
+    _default_qname = xsd_ns("int")
 
 
 class Short(Int):
-    _default_qname = xsd_ns('short')
+    _default_qname = xsd_ns("short")
 
 
 class Byte(Short):
     """A signed 8-bit integer"""
-    _default_qname = xsd_ns('byte')
+
+    _default_qname = xsd_ns("byte")
 
 
 class NonNegativeInteger(Integer):
-    _default_qname = xsd_ns('nonNegativeInteger')
+    _default_qname = xsd_ns("nonNegativeInteger")
 
 
 class UnsignedLong(NonNegativeInteger):
-    _default_qname = xsd_ns('unsignedLong')
+    _default_qname = xsd_ns("unsignedLong")
 
 
 class UnsignedInt(UnsignedLong):
-    _default_qname = xsd_ns('unsignedInt')
+    _default_qname = xsd_ns("unsignedInt")
 
 
 class UnsignedShort(UnsignedInt):
-    _default_qname = xsd_ns('unsignedShort')
+    _default_qname = xsd_ns("unsignedShort")
 
 
 class UnsignedByte(UnsignedShort):
-    _default_qname = xsd_ns('unsignedByte')
+    _default_qname = xsd_ns("unsignedByte")
 
 
 class PositiveInteger(NonNegativeInteger):
-    _default_qname = xsd_ns('positiveInteger')
+    _default_qname = xsd_ns("positiveInteger")
 
 
 ##
@@ -478,10 +497,10 @@ def _parse_timezone(val):
     if not val:
         return
 
-    if val == 'Z' or val == '+00:00':
+    if val == "Z" or val == "+00:00":
         return pytz.utc
 
-    negative = val.startswith('-')
+    negative = val.startswith("-")
     minutes = int(val[-2:])
     minutes += int(val[1:3]) * 60
 
@@ -492,17 +511,17 @@ def _parse_timezone(val):
 
 def _unparse_timezone(tzinfo):
     if not tzinfo:
-        return ''
+        return ""
 
     if tzinfo == pytz.utc:
-        return 'Z'
+        return "Z"
 
     hours = math.floor(tzinfo._minutes / 60)
     minutes = tzinfo._minutes % 60
 
     if hours > 0:
-        return '+%02d:%02d' % (hours, minutes)
-    return '-%02d:%02d' % (abs(hours), minutes)
+        return "+%02d:%02d" % (hours, minutes)
+    return "-%02d:%02d" % (abs(hours), minutes)
 
 
 _types = [
@@ -526,7 +545,6 @@ _types = [
     AnyURI,
     QName,
     Notation,
-
     # Derived
     NormalizedString,
     Token,
@@ -553,12 +571,9 @@ _types = [
     UnsignedLong,
     UnsignedShort,
     PositiveInteger,
-
     # Other
     AnyType,
     AnySimpleType,
 ]
 
-default_types = {
-    cls._default_qname: cls(is_global=True) for cls in _types
-}
+default_types = {cls._default_qname: cls(is_global=True) for cls in _types}
