@@ -20,15 +20,30 @@ class tags(object):
 
 
 for name in [
-    'schema', 'import', 'include',
-    'annotation', 'element', 'simpleType', 'complexType',
-    'simpleContent', 'complexContent',
-    'sequence', 'group', 'choice', 'all', 'list', 'union',
-    'attribute', 'any', 'anyAttribute', 'attributeGroup',
-    'restriction', 'extension', 'notation',
-
+    "schema",
+    "import",
+    "include",
+    "annotation",
+    "element",
+    "simpleType",
+    "complexType",
+    "simpleContent",
+    "complexContent",
+    "sequence",
+    "group",
+    "choice",
+    "all",
+    "list",
+    "union",
+    "attribute",
+    "any",
+    "anyAttribute",
+    "attributeGroup",
+    "restriction",
+    "extension",
+    "notation",
 ]:
-    attr = name if name not in keyword.kwlist else name + '_'
+    attr = name if name not in keyword.kwlist else name + "_"
     setattr(tags, attr, xsd_ns(name))
 
 
@@ -74,20 +89,21 @@ class SchemaVisitor(object):
         return result
 
     def process_ref_attribute(self, node, array_type=None):
-        ref = qname_attr(node, 'ref')
+        ref = qname_attr(node, "ref")
         if ref:
             ref = self._create_qname(ref)
 
             # Some wsdl's reference to xs:schema, we ignore that for now. It
             # might be better in the future to process the actual schema file
             # so that it is handled correctly
-            if ref.namespace == 'http://www.w3.org/2001/XMLSchema':
+            if ref.namespace == "http://www.w3.org/2001/XMLSchema":
                 return
             return xsd_elements.RefAttribute(
-                node.tag, ref, self.schema, array_type=array_type)
+                node.tag, ref, self.schema, array_type=array_type
+            )
 
     def process_reference(self, node, **kwargs):
-        ref = qname_attr(node, 'ref')
+        ref = qname_attr(node, "ref")
         if not ref:
             return
 
@@ -134,11 +150,11 @@ class SchemaVisitor(object):
         # A schema should always have a targetNamespace attribute, otherwise
         # it is called a chameleon schema. In that case the schema will inherit
         # the namespace of the enclosing schema/node.
-        tns = node.get('targetNamespace')
+        tns = node.get("targetNamespace")
         if tns:
             self.document._target_namespace = tns
-        self.document._element_form = node.get('elementFormDefault', 'unqualified')
-        self.document._attribute_form = node.get('attributeFormDefault', 'unqualified')
+        self.document._element_form = node.get("elementFormDefault", "unqualified")
+        self.document._attribute_form = node.get("attributeFormDefault", "unqualified")
 
         for child in node:
             self.process(child, parent=node)
@@ -163,11 +179,11 @@ class SchemaVisitor(object):
 
         """
         schema_node = None
-        namespace = node.get('namespace')
-        location = node.get('schemaLocation')
+        namespace = node.get("namespace")
+        location = node.get("schemaLocation")
         if location:
             location = normalize_location(
-                self.schema.settings, location, self.document._location
+                self.schema.settings, location, self.document._base_url
             )
 
         if not namespace and not self.document._target_namespace:
@@ -175,7 +191,8 @@ class SchemaVisitor(object):
                 "The attribute 'namespace' must be existent if the "
                 "importing schema has no target namespace.",
                 filename=self._document.location,
-                sourceline=node.sourceline)
+                sourceline=node.sourceline,
+            )
 
         # We found an empty <import/> statement, this needs to trigger 4.1.2
         # from https://www.w3.org/TR/2012/REC-xmlschema11-1-20120405/#src-resolve
@@ -189,7 +206,9 @@ class SchemaVisitor(object):
 
         # Check if the schema is already imported before based on the
         # namespace. Schema's without namespace are registered as 'None'
-        document = self.schema.documents.get_by_namespace_and_location(namespace, location)
+        document = self.schema.documents.get_by_namespace_and_location(
+            namespace, location
+        )
         if document:
             logger.debug("Returning existing schema: %r", location)
             self.register_import(namespace, document)
@@ -197,15 +216,17 @@ class SchemaVisitor(object):
 
         # Hardcode the mapping between the xml namespace and the xsd for now.
         # This seems to fix issues with exchange wsdl's, see #220
-        if not location and namespace == 'http://www.w3.org/XML/1998/namespace':
-            location = 'https://www.w3.org/2001/xml.xsd'
+        if not location and namespace == "http://www.w3.org/XML/1998/namespace":
+            location = "https://www.w3.org/2001/xml.xsd"
 
         # Silently ignore import statements which we can't resolve via the
         # namespace and doesn't have a schemaLocation attribute.
         if not location:
             logger.debug(
-                "Ignoring import statement for namespace %r " +
-                "(missing schemaLocation)", namespace)
+                "Ignoring import statement for namespace %r "
+                + "(missing schemaLocation)",
+                namespace,
+            )
             return
 
         # Load the XML
@@ -213,19 +234,23 @@ class SchemaVisitor(object):
             location,
             transport=self.schema._transport,
             base_url=self.document._location,
-            settings=self.schema.settings)
+            settings=self.schema.settings,
+        )
 
         # Check if the xsd:import namespace matches the targetNamespace. If
         # the xsd:import statement didn't specify a namespace then make sure
         # that the targetNamespace wasn't declared by another schema yet.
-        schema_tns = schema_node.get('targetNamespace')
+        schema_tns = schema_node.get("targetNamespace")
         if namespace and schema_tns and namespace != schema_tns:
-            raise XMLParseError((
-                "The namespace defined on the xsd:import doesn't match the "
-                "imported targetNamespace located at %r "
-                ) % (location),
+            raise XMLParseError(
+                (
+                    "The namespace defined on the xsd:import doesn't match the "
+                    "imported targetNamespace located at %r "
+                )
+                % (location),
                 filename=self.document._location,
-                sourceline=node.sourceline)
+                sourceline=node.sourceline,
+            )
 
         # If the imported schema doesn't define a target namespace and the
         # node doesn't specify it either then inherit the existing target
@@ -233,7 +258,9 @@ class SchemaVisitor(object):
         elif not schema_tns and not namespace:
             namespace = self.document._target_namespace
 
-        schema = self.schema.create_new_document(schema_node, location, target_namespace=namespace)
+        schema = self.schema.create_new_document(
+            schema_node, location, target_namespace=namespace
+        )
         self.register_import(namespace, schema)
         return schema
 
@@ -255,17 +282,19 @@ class SchemaVisitor(object):
         :type parent: lxml.etree._Element
 
         """
-        if not node.get('schemaLocation'):
+        if not node.get("schemaLocation"):
             raise NotImplementedError("schemaLocation is required")
-        location = node.get('schemaLocation')
+        location = node.get("schemaLocation")
 
         if location in self._includes:
             return
 
         schema_node = load_external(
-            location, self.schema._transport,
+            location,
+            self.schema._transport,
             base_url=self.document._base_url,
-            settings=self.schema.settings)
+            settings=self.schema.settings,
+        )
         self._includes.add(location)
 
         # When the included document has no default namespace defined but the
@@ -277,16 +306,18 @@ class SchemaVisitor(object):
         # Included schemas must have targetNamespace equal to parent schema (the including) or None.
         # If included schema doesn't have default ns, then it should be set to parent's targetNs.
         # See Chameleon Inclusion https://www.w3.org/TR/xmlschema11-1/#chameleon-xslt
-        if not schema_node.nsmap.get(None) and (node.nsmap.get(None) or parent.attrib.get('targetNamespace')):
-            nsmap = {None: node.nsmap.get(None) or parent.attrib['targetNamespace']}
+        if not schema_node.nsmap.get(None) and (
+            node.nsmap.get(None) or parent.attrib.get("targetNamespace")
+        ):
+            nsmap = {None: node.nsmap.get(None) or parent.attrib["targetNamespace"]}
             nsmap.update(schema_node.nsmap)
             new = etree.Element(schema_node.tag, nsmap=nsmap)
             for child in schema_node:
                 new.append(child)
             for key, value in schema_node.attrib.items():
                 new.set(key, value)
-            if not new.attrib.get('targetNamespace'):
-                new.attrib['targetNamespace'] = parent.attrib['targetNamespace']
+            if not new.attrib.get("targetNamespace"):
+                new.attrib["targetNamespace"] = parent.attrib["targetNamespace"]
             schema_node = new
 
         # Use the element/attribute form defaults from the schema while
@@ -295,8 +326,12 @@ class SchemaVisitor(object):
         attribute_form_default = self.document._attribute_form
         base_url = self.document._base_url
 
-        self.document._element_form = schema_node.get('elementFormDefault', 'unqualified')
-        self.document._attribute_form = schema_node.get('attributeFormDefault', 'unqualified')
+        self.document._element_form = schema_node.get(
+            "elementFormDefault", "unqualified"
+        )
+        self.document._attribute_form = schema_node.get(
+            "attributeFormDefault", "unqualified"
+        )
         self.document._base_url = absolute_location(location, self.document._base_url)
 
         # Iterate directly over the children.
@@ -356,15 +391,16 @@ class SchemaVisitor(object):
             if parent.tag == tags.choice:
                 min_occurs = 0
             result = self.process_reference(
-                node, min_occurs=min_occurs, max_occurs=max_occurs)
+                node, min_occurs=min_occurs, max_occurs=max_occurs
+            )
             if result:
                 return result
 
-        element_form = node.get('form', self.document._element_form)
-        if element_form == 'qualified' or is_global:
-            qname = qname_attr(node, 'name', self.document._target_namespace)
+        element_form = node.get("form", self.document._element_form)
+        if element_form == "qualified" or is_global:
+            qname = qname_attr(node, "name", self.document._target_namespace)
         else:
-            qname = etree.QName(node.get('name').strip())
+            qname = etree.QName(node.get("name").strip())
 
         children = list(node)
         xsd_type = None
@@ -381,18 +417,23 @@ class SchemaVisitor(object):
                     xsd_type = self.process(child, node)
 
         if not xsd_type:
-            node_type = qname_attr(node, 'type')
+            node_type = qname_attr(node, "type")
             if node_type:
                 xsd_type = self._get_type(node_type.text)
             else:
                 xsd_type = xsd_types.AnyType()
 
-        nillable = node.get('nillable') == 'true'
-        default = node.get('default')
+        nillable = node.get("nillable") == "true"
+        default = node.get("default")
         element = xsd_elements.Element(
-            name=qname, type_=xsd_type,
-            min_occurs=min_occurs, max_occurs=max_occurs, nillable=nillable,
-            default=default, is_global=is_global)
+            name=qname,
+            type_=xsd_type,
+            min_occurs=min_occurs,
+            max_occurs=max_occurs,
+            nillable=nillable,
+            default=default,
+            is_global=is_global,
+        )
 
         # Only register global elements
         if is_global:
@@ -426,9 +467,9 @@ class SchemaVisitor(object):
         is_global = parent.tag == tags.schema
 
         # Check of wsdl:arayType
-        array_type = node.get('{http://schemas.xmlsoap.org/wsdl/}arrayType')
+        array_type = node.get("{http://schemas.xmlsoap.org/wsdl/}arrayType")
         if array_type:
-            match = re.match(r'([^\[]+)', array_type)
+            match = re.match(r"([^\[]+)", array_type)
             if match:
                 array_type = match.groups()[0]
                 qname = as_qname(array_type, node.nsmap)
@@ -442,28 +483,29 @@ class SchemaVisitor(object):
             if result:
                 return result
 
-        attribute_form = node.get('form', self.document._attribute_form)
-        if attribute_form == 'qualified' or is_global:
-            name = qname_attr(node, 'name', self.document._target_namespace)
+        attribute_form = node.get("form", self.document._attribute_form)
+        if attribute_form == "qualified" or is_global:
+            name = qname_attr(node, "name", self.document._target_namespace)
         else:
-            name = etree.QName(node.get('name'))
+            name = etree.QName(node.get("name"))
 
         annotation, items = self._pop_annotation(list(node))
         if items:
             xsd_type = self.visit_simple_type(items[0], node)
         else:
-            node_type = qname_attr(node, 'type')
+            node_type = qname_attr(node, "type")
             if node_type:
                 xsd_type = self._get_type(node_type)
             else:
                 xsd_type = xsd_types.AnyType()
 
         # TODO: We ignore 'prohobited' for now
-        required = node.get('use') == 'required'
-        default = node.get('default')
+        required = node.get("use") == "required"
+        default = node.get("default")
 
         attr = xsd_elements.Attribute(
-            name, type_=xsd_type, default=default, required=required)
+            name, type_=xsd_type, default=default, required=required
+        )
 
         # Only register global elements
         if is_global:
@@ -490,12 +532,12 @@ class SchemaVisitor(object):
         """
 
         if parent.tag == tags.schema:
-            name = node.get('name')
+            name = node.get("name")
             is_global = True
         else:
-            name = parent.get('name', 'Anonymous')
+            name = parent.get("name", "Anonymous")
             is_global = False
-        base_type = '{http://www.w3.org/2001/XMLSchema}string'
+        base_type = "{http://www.w3.org/2001/XMLSchema}string"
         qname = as_qname(name, node.nsmap, self.document._target_namespace)
 
         annotation, items = self._pop_annotation(list(node))
@@ -541,22 +583,19 @@ class SchemaVisitor(object):
 
         """
         children = []
-        base_type = '{http://www.w3.org/2001/XMLSchema}anyType'
+        base_type = "{http://www.w3.org/2001/XMLSchema}anyType"
 
         # If the complexType's parent is an element then this type is
         # anonymous and should have no name defined. Otherwise it's global
         if parent.tag == tags.schema:
-            name = node.get('name')
+            name = node.get("name")
             is_global = True
         else:
-            name = parent.get('name')
+            name = parent.get("name")
             is_global = False
 
         qname = as_qname(name, node.nsmap, self.document._target_namespace)
-        cls_attributes = {
-            '__module__': 'zeep.xsd.dynamic_types',
-            '_xsd_name': qname,
-        }
+        cls_attributes = {"__module__": "zeep.xsd.dynamic_types", "_xsd_name": qname}
         xsd_cls = type(name, (xsd_types.ComplexType,), cls_attributes)
         xsd_type = None
 
@@ -568,8 +607,11 @@ class SchemaVisitor(object):
             base_type, attributes = self.visit_simple_content(children[0], node)
 
             xsd_type = xsd_cls(
-                attributes=attributes, extension=base_type, qname=qname,
-                is_global=is_global)
+                attributes=attributes,
+                extension=base_type,
+                qname=qname,
+                is_global=is_global,
+            )
 
         elif first_tag == tags.complexContent:
             kwargs = self.visit_complex_content(children[0], node)
@@ -584,8 +626,8 @@ class SchemaVisitor(object):
 
             attributes = self._process_attributes(node, children)
             xsd_type = xsd_cls(
-                element=element, attributes=attributes, qname=qname,
-                is_global=is_global)
+                element=element, attributes=attributes, qname=qname, is_global=is_global
+            )
         else:
             xsd_type = xsd_cls(qname=qname, is_global=is_global)
 
@@ -617,20 +659,14 @@ class SchemaVisitor(object):
 
         if child.tag == tags.restriction:
             base, element, attributes = self.visit_restriction_complex_content(
-                child, node)
-            return {
-                'attributes': attributes,
-                'element': element,
-                'restriction': base,
-            }
+                child, node
+            )
+            return {"attributes": attributes, "element": element, "restriction": base}
         elif child.tag == tags.extension:
             base, element, attributes = self.visit_extension_complex_content(
-                child, node)
-            return {
-                'attributes': attributes,
-                'element': element,
-                'extension': base,
-            }
+                child, node
+            )
+            return {"attributes": attributes, "element": element, "extension": base}
 
     def visit_simple_content(self, node, parent):
         """Contains extensions or restrictions on a complexType element with
@@ -682,7 +718,7 @@ class SchemaVisitor(object):
         :type parent: lxml.etree._Element
 
         """
-        base_name = qname_attr(node, 'base')
+        base_name = qname_attr(node, "base")
         if base_name:
             return self._get_type(base_name)
 
@@ -712,7 +748,7 @@ class SchemaVisitor(object):
         :type parent: lxml.etree._Element
 
         """
-        base_name = qname_attr(node, 'base')
+        base_name = qname_attr(node, "base")
         base_type = self._get_type(base_name)
         return base_type, []
 
@@ -735,7 +771,7 @@ class SchemaVisitor(object):
         :type parent: lxml.etree._Element
 
         """
-        base_name = qname_attr(node, 'base')
+        base_name = qname_attr(node, "base")
         base_type = self._get_type(base_name)
         annotation, children = self._pop_annotation(list(node))
 
@@ -770,7 +806,7 @@ class SchemaVisitor(object):
         :type parent: lxml.etree._Element
 
         """
-        base_name = qname_attr(node, 'base')
+        base_name = qname_attr(node, "base")
         base_type = self._get_type(base_name)
         annotation, children = self._pop_annotation(list(node))
 
@@ -798,7 +834,7 @@ class SchemaVisitor(object):
             Content: (annotation?, ((attribute | attributeGroup)*, anyAttribute?))
             </extension>
         """
-        base_name = qname_attr(node, 'base')
+        base_name = qname_attr(node, "base")
         base_type = self._get_type(base_name)
         annotation, children = self._pop_annotation(list(node))
         attributes = self._process_attributes(node, children)
@@ -847,10 +883,12 @@ class SchemaVisitor(object):
 
         """
         min_occurs, max_occurs = _process_occurs_attrs(node)
-        process_contents = node.get('processContents', 'strict')
+        process_contents = node.get("processContents", "strict")
         return xsd_elements.Any(
-            max_occurs=max_occurs, min_occurs=min_occurs,
-            process_contents=process_contents)
+            max_occurs=max_occurs,
+            min_occurs=min_occurs,
+            process_contents=process_contents,
+        )
 
     def visit_sequence(self, node, parent):
         """
@@ -873,18 +911,22 @@ class SchemaVisitor(object):
         """
 
         sub_types = [
-            tags.annotation, tags.any, tags.choice, tags.element,
-            tags.group, tags.sequence
+            tags.annotation,
+            tags.any,
+            tags.choice,
+            tags.element,
+            tags.group,
+            tags.sequence,
         ]
         min_occurs, max_occurs = _process_occurs_attrs(node)
-        result = xsd_elements.Sequence(
-            min_occurs=min_occurs, max_occurs=max_occurs)
+        result = xsd_elements.Sequence(min_occurs=min_occurs, max_occurs=max_occurs)
 
         annotation, children = self._pop_annotation(list(node))
         for child in children:
             if child.tag not in sub_types:
                 raise self._create_error(
-                    "Unexpected element %s in xsd:sequence" % child.tag, child)
+                    "Unexpected element %s in xsd:sequence" % child.tag, child
+                )
 
             item = self.process(child, node)
             assert item is not None
@@ -914,9 +956,7 @@ class SchemaVisitor(object):
 
         """
 
-        sub_types = [
-            tags.annotation, tags.element
-        ]
+        sub_types = [tags.annotation, tags.element]
         result = xsd_elements.All()
 
         annotation, children = self._pop_annotation(list(node))
@@ -954,11 +994,12 @@ class SchemaVisitor(object):
         min_occurs, max_occurs = _process_occurs_attrs(node)
 
         result = self.process_reference(
-            node, min_occurs=min_occurs, max_occurs=max_occurs)
+            node, min_occurs=min_occurs, max_occurs=max_occurs
+        )
         if result:
             return result
 
-        qname = qname_attr(node, 'name', self.document._target_namespace)
+        qname = qname_attr(node, "name", self.document._target_namespace)
 
         # There should be only max nodes, first node (annotation) is irrelevant
         annotation, children = self._pop_annotation(list(node))
@@ -992,7 +1033,7 @@ class SchemaVisitor(object):
 
 
         """
-        item_type = qname_attr(node, 'itemType')
+        item_type = qname_attr(node, "itemType")
         if item_type:
             sub_type = self._get_type(item_type.text)
         else:
@@ -1022,7 +1063,8 @@ class SchemaVisitor(object):
             elm = self.process(child, node)
             choices.append(elm)
         return xsd_elements.Choice(
-            choices, min_occurs=min_occurs, max_occurs=max_occurs)
+            choices, min_occurs=min_occurs, max_occurs=max_occurs
+        )
 
     def visit_union(self, node, parent):
         """Defines a collection of multiple simpleType definitions.
@@ -1043,7 +1085,7 @@ class SchemaVisitor(object):
 
         """
         # TODO
-        members = node.get('memberTypes')
+        members = node.get("memberTypes")
         types = []
         if members:
             for member in members.split():
@@ -1101,7 +1143,7 @@ class SchemaVisitor(object):
         if ref:
             return ref
 
-        qname = qname_attr(node, 'name', self.document._target_namespace)
+        qname = qname_attr(node, "name", self.document._target_namespace)
         annotation, children = self._pop_annotation(list(node))
 
         attributes = self._process_attributes(node, children)
@@ -1127,7 +1169,7 @@ class SchemaVisitor(object):
         :type parent: lxml.etree._Element
 
         """
-        process_contents = node.get('processContents', 'strict')
+        process_contents = node.get("processContents", "strict")
         return xsd_elements.AnyAttribute(process_contents=process_contents)
 
     def visit_notation(self, node, parent):
@@ -1164,28 +1206,29 @@ class SchemaVisitor(object):
             name = etree.QName(name)
 
         # Handle reserved namespace
-        if name.namespace == 'xml':
-            name = etree.QName(
-                'http://www.w3.org/XML/1998/namespace', name.localname)
+        if name.namespace == "xml":
+            name = etree.QName("http://www.w3.org/XML/1998/namespace", name.localname)
 
         # Various xsd builders assume that some schema's are available by
         # default (actually this is mostly just the soap-enc ns). So live with
         # that fact and handle it by auto-importing the schema if it is
         # referenced.
-        if (
-            name.namespace in AUTO_IMPORT_NAMESPACES
-            and not self.document.is_imported(name.namespace)
+        if name.namespace in AUTO_IMPORT_NAMESPACES and not self.document.is_imported(
+            name.namespace
         ):
-            logger.debug(
-                "Auto importing missing known schema: %s", name.namespace)
+            logger.debug("Auto importing missing known schema: %s", name.namespace)
             import_node = etree.Element(
-                tags.import_,
-                namespace=name.namespace, schemaLocation=name.namespace)
+                tags.import_, namespace=name.namespace, schemaLocation=name.namespace
+            )
             self.visit_import(import_node, None)
 
-        if (not name.namespace and self.document._element_form == 'qualified' and
-            self.document._target_namespace and not self.document._has_empty_import):
-                name = etree.QName(self.document._target_namespace, name.localname)
+        if (
+            not name.namespace
+            and self.document._element_form == "qualified"
+            and self.document._target_namespace
+            and not self.document._has_empty_import
+        ):
+            name = etree.QName(self.document._target_namespace, name.localname)
         return name
 
     def _pop_annotation(self, items):
@@ -1204,15 +1247,13 @@ class SchemaVisitor(object):
                 attribute = self.process(child, node)
                 attributes.append(attribute)
             else:
-                raise self._create_error(
-                    "Unexpected tag `%s`" % (child.tag), node)
+                raise self._create_error("Unexpected tag `%s`" % (child.tag), node)
         return attributes
 
     def _create_error(self, message, node):
         return XMLParseError(
-            message,
-            filename=self.document._location,
-            sourceline=node.sourceline)
+            message, filename=self.document._location, sourceline=node.sourceline
+        )
 
     visitors = {
         tags.any: visit_any,
@@ -1237,10 +1278,10 @@ class SchemaVisitor(object):
 
 def _process_occurs_attrs(node):
     """Process the min/max occurrence indicators"""
-    max_occurs = node.get('maxOccurs', '1')
-    min_occurs = int(node.get('minOccurs', '1'))
-    if max_occurs == 'unbounded':
-        max_occurs = 'unbounded'
+    max_occurs = node.get("maxOccurs", "1")
+    min_occurs = int(node.get("minOccurs", "1"))
+    if max_occurs == "unbounded":
+        max_occurs = "unbounded"
     else:
         max_occurs = int(max_occurs)
 
